/*
 *     Copyright 2015-2017 Austin Keener & Michael Ritter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.dv8tion.jda.core.entities;

import net.dv8tion.jda.core.utils.MiscUtil;

import java.util.Formattable;
import java.util.FormattableFlags;
import java.util.Formatter;

/**
 * Marks a mentionable entity.
 *
 * @since 3.0
 */
public interface IMentionable extends Formattable
{
    /**
     * Retrieve a Mention for this Entity.
     *
     * @return A resolvable mention.
     */
    String getAsMention();

    @Override
    default void formatTo(Formatter formatter, int flags, int width, int precision)
    {
        boolean leftJustified = (flags & FormattableFlags.LEFT_JUSTIFY) == FormattableFlags.LEFT_JUSTIFY;
        boolean upper = (flags & FormattableFlags.UPPERCASE) == FormattableFlags.UPPERCASE;
        String out = upper ? getAsMention().toUpperCase(formatter.locale()) : getAsMention();

        MiscUtil.appendTo(formatter, width, precision, leftJustified, out);
    }
}
